# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class QueryOrdersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryOrders','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ProductCode(self): # String
		return self.get_query_params().get('ProductCode')

	def set_ProductCode(self, ProductCode):  # String
		self.add_query_param('ProductCode', ProductCode)
	def get_SubscriptionType(self): # String
		return self.get_query_params().get('SubscriptionType')

	def set_SubscriptionType(self, SubscriptionType):  # String
		self.add_query_param('SubscriptionType', SubscriptionType)
	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_CreateTimeEnd(self): # String
		return self.get_query_params().get('CreateTimeEnd')

	def set_CreateTimeEnd(self, CreateTimeEnd):  # String
		self.add_query_param('CreateTimeEnd', CreateTimeEnd)
	def get_ProductType(self): # String
		return self.get_query_params().get('ProductType')

	def set_ProductType(self, ProductType):  # String
		self.add_query_param('ProductType', ProductType)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_PaymentStatus(self): # String
		return self.get_query_params().get('PaymentStatus')

	def set_PaymentStatus(self, PaymentStatus):  # String
		self.add_query_param('PaymentStatus', PaymentStatus)
	def get_CreateTimeStart(self): # String
		return self.get_query_params().get('CreateTimeStart')

	def set_CreateTimeStart(self, CreateTimeStart):  # String
		self.add_query_param('CreateTimeStart', CreateTimeStart)
	def get_OrderType(self): # String
		return self.get_query_params().get('OrderType')

	def set_OrderType(self, OrderType):  # String
		self.add_query_param('OrderType', OrderType)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class CreateAgAccountRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateAgAccount','bssopenapi')
		self.set_protocol_type('https')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_FirstName(self): # String
		return self.get_query_params().get('FirstName')

	def set_FirstName(self, FirstName):  # String
		self.add_query_param('FirstName', FirstName)
	def get_CityName(self): # String
		return self.get_query_params().get('CityName')

	def set_CityName(self, CityName):  # String
		self.add_query_param('CityName', CityName)
	def get_Postcode(self): # String
		return self.get_query_params().get('Postcode')

	def set_Postcode(self, Postcode):  # String
		self.add_query_param('Postcode', Postcode)
	def get_EnterpriseName(self): # String
		return self.get_query_params().get('EnterpriseName')

	def set_EnterpriseName(self, EnterpriseName):  # String
		self.add_query_param('EnterpriseName', EnterpriseName)
	def get_NationCode(self): # String
		return self.get_query_params().get('NationCode')

	def set_NationCode(self, NationCode):  # String
		self.add_query_param('NationCode', NationCode)
	def get_LastName(self): # String
		return self.get_query_params().get('LastName')

	def set_LastName(self, LastName):  # String
		self.add_query_param('LastName', LastName)
	def get_LoginEmail(self): # String
		return self.get_query_params().get('LoginEmail')

	def set_LoginEmail(self, LoginEmail):  # String
		self.add_query_param('LoginEmail', LoginEmail)
	def get_ProvinceName(self): # String
		return self.get_query_params().get('ProvinceName')

	def set_ProvinceName(self, ProvinceName):  # String
		self.add_query_param('ProvinceName', ProvinceName)
	def get_AccountAttr(self): # String
		return self.get_query_params().get('AccountAttr')

	def set_AccountAttr(self, AccountAttr):  # String
		self.add_query_param('AccountAttr', AccountAttr)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class CreateInstanceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'CreateInstance','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ProductCode(self): # String
		return self.get_query_params().get('ProductCode')

	def set_ProductCode(self, ProductCode):  # String
		self.add_query_param('ProductCode', ProductCode)
	def get_Period(self): # Integer
		return self.get_query_params().get('Period')

	def set_Period(self, Period):  # Integer
		self.add_query_param('Period', Period)
	def get_ClientToken(self): # String
		return self.get_query_params().get('ClientToken')

	def set_ClientToken(self, ClientToken):  # String
		self.add_query_param('ClientToken', ClientToken)
	def get_SubscriptionType(self): # String
		return self.get_query_params().get('SubscriptionType')

	def set_SubscriptionType(self, SubscriptionType):  # String
		self.add_query_param('SubscriptionType', SubscriptionType)
	def get_Logistics(self): # String
		return self.get_query_params().get('Logistics')

	def set_Logistics(self, Logistics):  # String
		self.add_query_param('Logistics', Logistics)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_ProductType(self): # String
		return self.get_query_params().get('ProductType')

	def set_ProductType(self, ProductType):  # String
		self.add_query_param('ProductType', ProductType)
	def get_RenewPeriod(self): # Integer
		return self.get_query_params().get('RenewPeriod')

	def set_RenewPeriod(self, RenewPeriod):  # Integer
		self.add_query_param('RenewPeriod', RenewPeriod)
	def get_RenewalStatus(self): # String
		return self.get_query_params().get('RenewalStatus')

	def set_RenewalStatus(self, RenewalStatus):  # String
		self.add_query_param('RenewalStatus', RenewalStatus)
	def get_Parameters(self): # RepeatList
		return self.get_query_params().get('Parameter')

	def set_Parameters(self, Parameter):  # RepeatList
		for depth1 in range(len(Parameter)):
			if Parameter[depth1].get('Code') is not None:
				self.add_query_param('Parameter.' + str(depth1 + 1) + '.Code', Parameter[depth1].get('Code'))
			if Parameter[depth1].get('Value') is not None:
				self.add_query_param('Parameter.' + str(depth1 + 1) + '.Value', Parameter[depth1].get('Value'))



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class DescribeProductAmortizedCostByConsumePeriodRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'DescribeProductAmortizedCostByConsumePeriod','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ProductDetail(self): # String
		return self.get_body_params().get('ProductDetail')

	def set_ProductDetail(self, ProductDetail):  # String
		self.add_body_params('ProductDetail', ProductDetail)
	def get_ProductCode(self): # String
		return self.get_body_params().get('ProductCode')

	def set_ProductCode(self, ProductCode):  # String
		self.add_body_params('ProductCode', ProductCode)
	def get_BillOwnerIdLists(self): # RepeatList
		return self.get_body_params().get('BillOwnerIdList')

	def set_BillOwnerIdLists(self, BillOwnerIdList):  # RepeatList
		for depth1 in range(len(BillOwnerIdList)):
			self.add_body_params('BillOwnerIdList.' + str(depth1 + 1), BillOwnerIdList[depth1])
	def get_SubscriptionType(self): # String
		return self.get_body_params().get('SubscriptionType')

	def set_SubscriptionType(self, SubscriptionType):  # String
		self.add_body_params('SubscriptionType', SubscriptionType)
	def get_BillingCycle(self): # String
		return self.get_body_params().get('BillingCycle')

	def set_BillingCycle(self, BillingCycle):  # String
		self.add_body_params('BillingCycle', BillingCycle)
	def get_CostUnitCode(self): # String
		return self.get_body_params().get('CostUnitCode')

	def set_CostUnitCode(self, CostUnitCode):  # String
		self.add_body_params('CostUnitCode', CostUnitCode)
	def get_AmortizationPeriodFilters(self): # RepeatList
		return self.get_body_params().get('AmortizationPeriodFilter')

	def set_AmortizationPeriodFilters(self, AmortizationPeriodFilter):  # RepeatList
		for depth1 in range(len(AmortizationPeriodFilter)):
			self.add_body_params('AmortizationPeriodFilter.' + str(depth1 + 1), AmortizationPeriodFilter[depth1])
	def get_NextToken(self): # String
		return self.get_body_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_body_params('NextToken', NextToken)
	def get_BillUserIdLists(self): # RepeatList
		return self.get_body_params().get('BillUserIdList')

	def set_BillUserIdLists(self, BillUserIdList):  # RepeatList
		for depth1 in range(len(BillUserIdList)):
			self.add_body_params('BillUserIdList.' + str(depth1 + 1), BillUserIdList[depth1])
	def get_MaxResults(self): # Integer
		return self.get_body_params().get('MaxResults')

	def set_MaxResults(self, MaxResults):  # Integer
		self.add_body_params('MaxResults', MaxResults)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class QueryRIUtilizationDetailRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryRIUtilizationDetail','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_DeductedInstanceId(self): # String
		return self.get_query_params().get('DeductedInstanceId')

	def set_DeductedInstanceId(self, DeductedInstanceId):  # String
		self.add_query_param('DeductedInstanceId', DeductedInstanceId)
	def get_InstanceSpec(self): # String
		return self.get_query_params().get('InstanceSpec')

	def set_InstanceSpec(self, InstanceSpec):  # String
		self.add_query_param('InstanceSpec', InstanceSpec)
	def get_EndTime(self): # String
		return self.get_query_params().get('EndTime')

	def set_EndTime(self, EndTime):  # String
		self.add_query_param('EndTime', EndTime)
	def get_RIInstanceId(self): # String
		return self.get_query_params().get('RIInstanceId')

	def set_RIInstanceId(self, RIInstanceId):  # String
		self.add_query_param('RIInstanceId', RIInstanceId)
	def get_StartTime(self): # String
		return self.get_query_params().get('StartTime')

	def set_StartTime(self, StartTime):  # String
		self.add_query_param('StartTime', StartTime)
	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_RICommodityCode(self): # String
		return self.get_query_params().get('RICommodityCode')

	def set_RICommodityCode(self, RICommodityCode):  # String
		self.add_query_param('RICommodityCode', RICommodityCode)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class QueryEvaluateListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryEvaluateList','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_EndSearchTime(self): # String
		return self.get_query_params().get('EndSearchTime')

	def set_EndSearchTime(self, EndSearchTime):  # String
		self.add_query_param('EndSearchTime', EndSearchTime)
	def get_OutBizId(self): # String
		return self.get_query_params().get('OutBizId')

	def set_OutBizId(self, OutBizId):  # String
		self.add_query_param('OutBizId', OutBizId)
	def get_SortType(self): # Integer
		return self.get_query_params().get('SortType')

	def set_SortType(self, SortType):  # Integer
		self.add_query_param('SortType', SortType)
	def get_Type(self): # Integer
		return self.get_query_params().get('Type')

	def set_Type(self, Type):  # Integer
		self.add_query_param('Type', Type)
	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_EndAmount(self): # Long
		return self.get_query_params().get('EndAmount')

	def set_EndAmount(self, EndAmount):  # Long
		self.add_query_param('EndAmount', EndAmount)
	def get_BillCycle(self): # String
		return self.get_query_params().get('BillCycle')

	def set_BillCycle(self, BillCycle):  # String
		self.add_query_param('BillCycle', BillCycle)
	def get_BizTypeLists(self): # RepeatList
		return self.get_query_params().get('BizTypeList')

	def set_BizTypeLists(self, BizTypeList):  # RepeatList
		for depth1 in range(len(BizTypeList)):
			self.add_query_param('BizTypeList.' + str(depth1 + 1), BizTypeList[depth1])
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_StartSearchTime(self): # String
		return self.get_query_params().get('StartSearchTime')

	def set_StartSearchTime(self, StartSearchTime):  # String
		self.add_query_param('StartSearchTime', StartSearchTime)
	def get_EndBizTime(self): # String
		return self.get_query_params().get('EndBizTime')

	def set_EndBizTime(self, EndBizTime):  # String
		self.add_query_param('EndBizTime', EndBizTime)
	def get_StartAmount(self): # Long
		return self.get_query_params().get('StartAmount')

	def set_StartAmount(self, StartAmount):  # Long
		self.add_query_param('StartAmount', StartAmount)
	def get_StartBizTime(self): # String
		return self.get_query_params().get('StartBizTime')

	def set_StartBizTime(self, StartBizTime):  # String
		self.add_query_param('StartBizTime', StartBizTime)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class ApplyInvoiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'ApplyInvoice','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InvoicingType(self): # Integer
		return self.get_query_params().get('InvoicingType')

	def set_InvoicingType(self, InvoicingType):  # Integer
		self.add_query_param('InvoicingType', InvoicingType)
	def get_ProcessWay(self): # Integer
		return self.get_query_params().get('ProcessWay')

	def set_ProcessWay(self, ProcessWay):  # Integer
		self.add_query_param('ProcessWay', ProcessWay)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_InvoiceAmount(self): # Long
		return self.get_query_params().get('InvoiceAmount')

	def set_InvoiceAmount(self, InvoiceAmount):  # Long
		self.add_query_param('InvoiceAmount', InvoiceAmount)
	def get_AddressId(self): # Long
		return self.get_query_params().get('AddressId')

	def set_AddressId(self, AddressId):  # Long
		self.add_query_param('AddressId', AddressId)
	def get_ApplyUserNick(self): # String
		return self.get_query_params().get('ApplyUserNick')

	def set_ApplyUserNick(self, ApplyUserNick):  # String
		self.add_query_param('ApplyUserNick', ApplyUserNick)
	def get_InvoiceByAmount(self): # Boolean
		return self.get_query_params().get('InvoiceByAmount')

	def set_InvoiceByAmount(self, InvoiceByAmount):  # Boolean
		self.add_query_param('InvoiceByAmount', InvoiceByAmount)
	def get_CustomerId(self): # Long
		return self.get_query_params().get('CustomerId')

	def set_CustomerId(self, CustomerId):  # Long
		self.add_query_param('CustomerId', CustomerId)
	def get_SelectedIdss(self): # RepeatList
		return self.get_query_params().get('SelectedIds')

	def set_SelectedIdss(self, SelectedIds):  # RepeatList
		for depth1 in range(len(SelectedIds)):
			self.add_query_param('SelectedIds.' + str(depth1 + 1), SelectedIds[depth1])
	def get_UserRemark(self): # String
		return self.get_query_params().get('UserRemark')

	def set_UserRemark(self, UserRemark):  # String
		self.add_query_param('UserRemark', UserRemark)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class QueryAccountTransactionsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'QueryAccountTransactions','bssopenapi')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_PageNum(self): # Integer
		return self.get_query_params().get('PageNum')

	def set_PageNum(self, PageNum):  # Integer
		self.add_query_param('PageNum', PageNum)
	def get_TransactionType(self): # String
		return self.get_query_params().get('TransactionType')

	def set_TransactionType(self, TransactionType):  # String
		self.add_query_param('TransactionType', TransactionType)
	def get_CreateTimeEnd(self): # String
		return self.get_query_params().get('CreateTimeEnd')

	def set_CreateTimeEnd(self, CreateTimeEnd):  # String
		self.add_query_param('CreateTimeEnd', CreateTimeEnd)
	def get_RecordID(self): # String
		return self.get_query_params().get('RecordID')

	def set_RecordID(self, RecordID):  # String
		self.add_query_param('RecordID', RecordID)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_TransactionChannel(self): # String
		return self.get_query_params().get('TransactionChannel')

	def set_TransactionChannel(self, TransactionChannel):  # String
		self.add_query_param('TransactionChannel', TransactionChannel)
	def get_TransactionChannelSN(self): # String
		return self.get_query_params().get('TransactionChannelSN')

	def set_TransactionChannelSN(self, TransactionChannelSN):  # String
		self.add_query_param('TransactionChannelSN', TransactionChannelSN)
	def get_CreateTimeStart(self): # String
		return self.get_query_params().get('CreateTimeStart')

	def set_CreateTimeStart(self, CreateTimeStart):  # String
		self.add_query_param('CreateTimeStart', CreateTimeStart)
	def get_TransactionNumber(self): # String
		return self.get_query_params().get('TransactionNumber')

	def set_TransactionNumber(self, TransactionNumber):  # String
		self.add_query_param('TransactionNumber', TransactionNumber)
	def get_TransactionFlow(self): # String
		return self.get_query_params().get('TransactionFlow')

	def set_TransactionFlow(self, TransactionFlow):  # String
		self.add_query_param('TransactionFlow', TransactionFlow)



# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkbssopenapi.endpoint import endpoint_data

class SetCreditLabelActionRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'BssOpenApi', '2017-12-14', 'SetCreditLabelAction','bssopenapi')
		self.set_protocol_type('https')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ActionType(self): # String
		return self.get_query_params().get('ActionType')

	def set_ActionType(self, ActionType):  # String
		self.add_query_param('ActionType', ActionType)
	def get_IsNeedSaveNotifyRule(self): # String
		return self.get_query_params().get('IsNeedSaveNotifyRule')

	def set_IsNeedSaveNotifyRule(self, IsNeedSaveNotifyRule):  # String
		self.add_query_param('IsNeedSaveNotifyRule', IsNeedSaveNotifyRule)
	def get_IsNeedAdjustCreditAccount(self): # String
		return self.get_query_params().get('IsNeedAdjustCreditAccount')

	def set_IsNeedAdjustCreditAccount(self, IsNeedAdjustCreditAccount):  # String
		self.add_query_param('IsNeedAdjustCreditAccount', IsNeedAdjustCreditAccount)
	def get_NewCreateMode(self): # Boolean
		return self.get_query_params().get('NewCreateMode')

	def set_NewCreateMode(self, NewCreateMode):  # Boolean
		self.add_query_param('NewCreateMode', NewCreateMode)
	def get_Description(self): # String
		return self.get_query_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_query_param('Description', Description)
	def get_Source(self): # String
		return self.get_query_params().get('Source')

	def set_Source(self, Source):  # String
		self.add_query_param('Source', Source)
	def get_CurrencyCode(self): # String
		return self.get_query_params().get('CurrencyCode')

	def set_CurrencyCode(self, CurrencyCode):  # String
		self.add_query_param('CurrencyCode', CurrencyCode)
	def get_DailyCycle(self): # String
		return self.get_query_params().get('DailyCycle')

	def set_DailyCycle(self, DailyCycle):  # String
		self.add_query_param('DailyCycle', DailyCycle)
	def get_Operator(self): # String
		return self.get_query_params().get('Operator')

	def set_Operator(self, Operator):  # String
		self.add_query_param('Operator', Operator)
	def get_Uid(self): # String
		return self.get_query_params().get('Uid')

	def set_Uid(self, Uid):  # String
		self.add_query_param('Uid', Uid)
	def get_SiteCode(self): # String
		return self.get_query_params().get('SiteCode')

	def set_SiteCode(self, SiteCode):  # String
		self.add_query_param('SiteCode', SiteCode)
	def get_ClearCycle(self): # String
		return self.get_query_params().get('ClearCycle')

	def set_ClearCycle(self, ClearCycle):  # String
		self.add_query_param('ClearCycle', ClearCycle)
	def get_NeedNotice(self): # Boolean
		return self.get_query_params().get('NeedNotice')

	def set_NeedNotice(self, NeedNotice):  # Boolean
		self.add_query_param('NeedNotice', NeedNotice)
	def get_RequestId(self): # String
		return self.get_query_params().get('RequestId')

	def set_RequestId(self, RequestId):  # String
		self.add_query_param('RequestId', RequestId)
	def get_IsNeedSetCreditAmount(self): # String
		return self.get_query_params().get('IsNeedSetCreditAmount')

	def set_IsNeedSetCreditAmount(self, IsNeedSetCreditAmount):  # String
		self.add_query_param('IsNeedSetCreditAmount', IsNeedSetCreditAmount)
	def get_CreditAmount(self): # String
		return self.get_query_params().get('CreditAmount')

	def set_CreditAmount(self, CreditAmount):  # String
		self.add_query_param('CreditAmount', CreditAmount)
	def get_IsNeedAddSettleLabel(self): # String
		return self.get_query_params().get('IsNeedAddSettleLabel')

	def set_IsNeedAddSettleLabel(self, IsNeedAddSettleLabel):  # String
		self.add_query_param('IsNeedAddSettleLabel', IsNeedAddSettleLabel)
